@@ -20,7 +20,7 @@
 
 #include "./mfx_dispatcher_vpl_log.h"
 
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
     #include <windows.h>
 
     // use wide char on Windows
@@ -39,7 +39,7 @@ typedef std::string STRING_TYPE;
 typedef char CHAR_TYPE;
 #endif
 
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
     #if defined _M_IX86
         // Windows x86
         #define MSDK_LIB_NAME L"libmfxhw32."
@@ -48,7 +48,7 @@ typedef char CHAR_TYPE;
         #define MSDK_LIB_NAME L"libmfxhw64."
     #endif
     #define ONEVPL_PRIORITY_PATH_VAR L"ONEVPL_PRIORITY_PATH"
-#elif defined(__linux__) || defined(__CYGWIN__)
+#elif defined(__linux__)
     // Linux x64
     #define MSDK_LIB_NAME            "libmfxhw64."
     #define ONEVPL_PRIORITY_PATH_VAR "ONEVPL_PRIORITY_PATH"
