@@ -12,7 +12,7 @@
     #include "src/mfx_dispatcher_vpl_win.h"
 #endif
 #ifdef __CYGWIN__
-#define wcstombs_s(a,b,c,d,e) wcstombs(b,d,c)
+#define wcstombs_s(a,b,c,d,e) ((void)(a), (void)(e), wcstombs(b,d,c))
 #endif
 
 // leave table formatting alone
@@ -41,7 +41,7 @@ static const VPLFunctionDesc FunctionDescOptional[NumVPLOptionalFunctions] = {
 };
 
 static const VPLFunctionDesc MSDKCompatFunctions[NumMSDKFunctions] = {
-    { "MFXInitEx",                              { { 14, 1 } } },
+    { "MFXInit",                                { {  0, 1 } } },
     { "MFXClose" ,                              { {  0, 1 } } },
 };
 
