@@ -7,14 +7,17 @@
 #include <fstream>
 #include "src/mfx_dispatcher_vpl.h"
 
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
     #include "src/mfx_dispatcher_vpl_win.h"
 #endif
 
-#if defined(__linux__) || defined(__CYGWIN__)
+#ifdef __linux__
     #include <pthread.h>
     #define strncpy_s(dst, size, src, cnt) strncpy((dst), (src), (cnt)) // NOLINT
 #endif
+#ifdef __CYGWIN__
+    #define strncpy_s(dst, size, src, cnt) strncpy((dst), (src), (cnt)) // NOLINT
+#endif
 
 // leave table formatting alone
 // clang-format off
@@ -97,7 +100,7 @@ static const mfxImplementedFunctions msdkImplFuncs = {
     (mfxChar**)msdkImplFuncsNames
 };
 
-#if defined(__linux__) || defined(__CYGWIN__)
+#ifdef __linux__
 // optional extBuf to limit threads created in MSDK session creation
 // to enable, set vplParam.NumExtParam and vplParam.ExtParam before calling MFXInitEx2()
 static const mfxExtThreadsParam extThreadParam = {
@@ -142,7 +145,7 @@ mfxStatus LoaderCtxMSDK::OpenSession(mfxSession *session,
     mfxInitializationParam vplParam = {};
     vplParam.AccelerationMode       = accelMode;
 
-#if defined(__linux__) || defined(__CYGWIN__)
+#ifdef __linux__
     vplParam.ExtParam    = (mfxExtBuffer **)&extParams;
     vplParam.NumExtParam = 1;
 #else
@@ -183,7 +186,7 @@ mfxAccelerationMode LoaderCtxMSDK::CvtAccelType(mfxIMPL implType, mfxIMPL implMe
 }
 
 mfxStatus LoaderCtxMSDK::GetDefaultAccelType(mfxU32 adapterID, mfxIMPL *implDefault, mfxU64 *luid) {
-#if defined(__linux__) || defined(__CYGWIN__)
+#ifdef __linux__
     // VAAPI only
     *implDefault = MFX_IMPL_VIA_VAAPI;
     *luid        = 0;
@@ -235,7 +238,7 @@ mfxStatus LoaderCtxMSDK::QueryAPIVersion(STRING_TYPE libNameFull, mfxVersion *ms
         vplParam.AccelerationMode =
             (mfxAccelerationMode)CvtAccelType(MFX_IMPL_HARDWARE, implDefault & 0xFF00);
 
-#if defined(__linux__) || defined(__CYGWIN__)
+#ifdef __linux__
         vplParam.ExtParam    = (mfxExtBuffer **)&extParams;
         vplParam.NumExtParam = 1;
 #else
@@ -279,7 +282,7 @@ mfxStatus LoaderCtxMSDK::QueryMSDKCaps(STRING_TYPE libNameFull,
     m_libNameFull = libNameFull;
     m_deviceID    = 0;
 
-#if defined(__linux__) || defined(__CYGWIN__)
+#ifdef __linux__
     // require pthreads to be linked in for MSDK RT to load
     pthread_key_t pkey;
     if (pthread_key_create(&pkey, NULL) == 0) {
@@ -411,7 +414,7 @@ mfxStatus LoaderCtxMSDK::QueryMSDKCaps(STRING_TYPE libNameFull,
 
     CloseSession(&session);
 
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
     if (bSkipD3D9Check == false) {
         mfxIMPL implD3D9;
         m_msdkAdapterD3D9 = MFX_IMPL_UNSUPPORTED;
@@ -430,7 +433,7 @@ mfxStatus LoaderCtxMSDK::QueryMSDKCaps(STRING_TYPE libNameFull,
 }
 
 mfxStatus LoaderCtxMSDK::CheckD3D9Support(mfxU64 luid, STRING_TYPE libNameFull, mfxIMPL *implD3D9) {
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
     mfxU32 VendorID = 0, DeviceID = 0;
     mfxIMPL implTest = MFX_IMPL_VIA_D3D9;
 
@@ -510,7 +513,7 @@ mfxStatus LoaderCtxMSDK::GetRenderNodeDescription(mfxU32 adapterID,
     vendorID = 0;
     deviceID = 0;
 
-#if defined(__linux__) || defined(__CYGWIN__)
+#if defined(__linux__)
     mfxU32 DRMRenderNodeNum = 128 + adapterID;
     std::string nodeStr     = std::to_string(DRMRenderNodeNum);
 
@@ -570,7 +573,7 @@ mfxStatus LoaderCtxMSDK::QueryExtDeviceID(mfxExtendedDeviceId *extDeviceID,
 
     snprintf(extDeviceID->DeviceName, sizeof(extDeviceID->DeviceName), "%s", strImplName);
 
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
     // fill in Windows-specific properties
     if (luid) {
         extDeviceID->LUIDDeviceNodeMask = 1;
@@ -583,7 +586,7 @@ mfxStatus LoaderCtxMSDK::QueryExtDeviceID(mfxExtendedDeviceId *extDeviceID,
             luidArr >>= 8;
         }
     }
-#elif defined(__linux__) || defined(__CYGWIN__)
+#elif defined(__linux__)
     extDeviceID->DRMPrimaryNodeNum = adapterID;
     extDeviceID->DRMRenderNodeNum  = 128 + adapterID;
 #endif
